==> riece-2.0.0.tar.gz: riece-2.0.0/lisp/riece-addon-modules.el <==
(defconst riece-addon-modules
  '((riece-alias . "Define aliases for IRC names.")
    (riece-async . "Connect to IRC server via async proxy.")
    (riece-biff . "Be notified if messages arrives.")
    (riece-button . "Display useful buttons in IRC buffers.")
    (riece-ctcp . "CTCP (Client To Client Protocol) support.")
    (riece-ctlseq . "Mark up control sequences in IRC buffers.")
    (riece-doctor . "Pretend to be a psychotherapist.")
    (riece-eval-ruby . "Evaluate input string as a Ruby program.")
    (riece-eval . "Evaluate an input string as an elisp form.")
    (riece-foolproof . "Prevent miss-operation in the command buffer.")
    (riece-google . "Search keywords by Google.")
    (riece-guess . "Guess the next channel, using multiple methods.")
    (riece-hangman . "Allow channel members to play the hangman game.")
    (riece-highlight . "Highlight IRC buffers.")
    (riece-history . "Manage history of channel shifting.")
    (riece-icon . "Display icons in IRC buffers.")
    (riece-ignore . "Ignore messages from some users.")
    (riece-kakasi . "Convert Japanese to roman string by KAKASI.")
    (riece-keepalive . "Keep an IRC connection.")
    (riece-keyword . "Detect keywords in IRC buffers.")
    (riece-log . "Save IRC logs.")
    (riece-lsdb . "Help register nicknames in LSDB rolodex program.")
    (riece-menu . "Setup Riece's command menus.")
    (riece-mini . "Use Riece only on the minibuffer.")
    ;;(riece-ndcc . "DCC file sending protocol support (written in elisp.)")
    (riece-rdcc . "DCC file sending protocol support (written in Ruby.)")
    (riece-shrink-buffer . "Free old IRC messages to save memory usage.")
    (riece-skk-kakutei . "Remove SKK's preedit mark before sending messages.")
    (riece-toolbar . "Display toolbar icons.")
    (riece-unread . "Mark channels where new messages arrived.")
    (riece-url . "Collect URL in IRC buffers.")
    (riece-xface . "Display X-Face in IRC buffers.")
    (riece-yank . "Enter the element of kill-ring.")))

(provide 'riece-addon-modules)

==> riece_3.0.0.orig.tar.gz: riece-3.0.0/lisp/riece-addon-modules.el <==
(defconst riece-addon-modules
  '((riece-alias . "Define aliases for IRC names.")
    (riece-async . "Connect to IRC server via async proxy.")
    (riece-biff . "Be notified if messages arrives.")
    (riece-button . "Display useful buttons in IRC buffers.")
    (riece-ctcp . "CTCP (Client To Client Protocol) support.")
    (riece-ctlseq . "Mark up control sequences in IRC buffers.")
    (riece-doctor . "Pretend to be a psychotherapist.")
    (riece-epg . "Encrypt/decrypt messages.")
    (riece-eval-ruby . "Evaluate input string as a Ruby program.")
    (riece-eval . "Evaluate an input string as an elisp form.")
    (riece-foolproof . "Prevent miss-operation in the command buffer.")
    (riece-google . "Search keywords by Google.")
    (riece-guess . "Guess the next channel, using multiple methods.")
    (riece-hangman . "Allow channel members to play the hangman game.")
    (riece-highlight . "Highlight IRC buffers.")
    (riece-history . "Manage history of channel shifting.")
    (riece-icon . "Display icons in IRC buffers.")
    (riece-ignore . "Ignore messages from some users.")
    (riece-kakasi . "Convert Japanese to roman string by KAKASI.")
    (riece-keepalive . "Keep an IRC connection.")
    (riece-keyword . "Detect keywords in IRC buffers.")
    (riece-log . "Save IRC logs.")
    (riece-lsdb . "Help register nicknames in LSDB rolodex program.")
    (riece-menu . "Setup Riece's command menus.")
    (riece-mini . "Use Riece only on the minibuffer.")
    ;;(riece-ndcc . "DCC file sending protocol support (written in elisp.)")
    (riece-rdcc . "DCC file sending protocol support (written in Ruby.)")
    (riece-shrink-buffer . "Free old IRC messages to save memory usage.")
    (riece-skk-kakutei . "Remove SKK's preedit mark before sending messages.")
    (riece-toolbar . "Display toolbar icons.")
    (riece-unread . "Mark channels where new messages arrived.")
    (riece-url . "Collect URL in IRC buffers.")
    (riece-xface . "Display X-Face in IRC buffers.")
    (riece-xfaceb . "Display X-Face & Colour Face images in IRC buffers \(BBDB\).")
    (riece-yank . "Enter the element of kill-ring.")))

(provide 'riece-addon-modules)
